@@ -507,7 +507,7 @@ class RecData (Pluggable):
                 # https://sourceforge.net/projects/grecipe-manager/forums/forum/371768/topic/3630545?message=8205906
                 try:
                     self.db.connect().execute('select recipe_id from ingredients')
-                except sqlite3.OperationalError:
+                except sqlalchemy.exc.OperationalError:
                     self.alter_table('ingredients',self.setup_ingredient_table,
                                      {'id':'recipe_id'},
                                      ['refid', 'unit', 'amount', 'rangeamount',
@@ -811,12 +811,14 @@ class RecData (Pluggable):
     def get_unique_values (self, colname,table=None,**criteria):
         """Get list of unique values for column in table."""
         if table is None: table=self.recipe_table
-        if criteria: table = table.select(*make_simple_select_arg(criteria,table))
+        if criteria: criteria = make_simple_select_arg(criteria,table)[0]
+        else: criteria=None
         if colname=='category' and table==self.recipe_table:
             print 'WARNING: you are using a hack to access category values.'
-            table=self.categories_table
+            table = self.categories_table
+            table = table.alias('ingrtable')
         retval = [r[0] for
-                  r in sqlalchemy.select([getattr(table.c,colname)],distinct=True).execute().fetchall()
+                  r in sqlalchemy.select([getattr(table.c,colname)],distinct=True,whereclause=criteria).execute().fetchall()
                   ]
         return filter(lambda x: x is not None, retval) # Don't return null values
 
@@ -832,23 +834,24 @@ class RecData (Pluggable):
                 criteria = col.op('REGEXP')(search['search'])
             else:
                 criteria = col==crit['search']
+            result =  sqlalchemy.select(
+                [sqlalchemy.func.count(self.ingredients_table.c.ingkey).label('count'),
+                 self.ingredients_table.c.ingkey],
+                criteria,
+                **{'group_by':'ingkey',
+                   'order_by':make_order_by([],self.ingredients_table,count_by='ingkey'),
+                   }
+                ).execute().fetchall()                
         else:
-            criteria = []
-        result =  sqlalchemy.select(
-            [sqlalchemy.func.count(self.ingredients_table.c.ingkey).label('count'),
-             self.ingredients_table.c.ingkey],
-            criteria,
-            **{'group_by':'ingkey',
-               'order_by':make_order_by([],self.ingredients_table,count_by='ingkey'),
-               }
-            ).execute().fetchall()
+            result =  sqlalchemy.select(
+                [sqlalchemy.func.count(self.ingredients_table.c.ingkey).label('count'),
+                 self.ingredients_table.c.ingkey],
+                **{'group_by':'ingkey',
+                   'order_by':make_order_by([],self.ingredients_table,count_by='ingkey'),
+                   }
+                ).execute().fetchall()
+
         return result
-        return self.fetch_count(self.ingredients_table,'ingkey',)
-        s = sqlalchemy.select([
-            self.ingredients_table.c.ingkey,
-            func.count(self.ingredients_table.c.ingkey).label('count')
-            ]).execute()
-        return s.fetchall()
 
     def delete_by_criteria (self, table, criteria):
         """Table is our table.
@@ -888,7 +891,11 @@ class RecData (Pluggable):
         """
         name = table.name; new_col = column_spec[0]; coltyp = column_spec[1]
         if hasattr(coltyp ,'dialect_impl'):
-            coltyp = coltyp.dialect_impl(self.db.dialect).get_col_spec()
+            try:
+                coltyp = coltyp.dialect_impl(self.db.dialect).get_col_spec()
+            except AttributeError:
+                # SQL 0.6
+                coltyp = coltyp.compile(dialect=self.db.dialect)
         sql = 'ALTER TABLE %(name)s ADD %(new_col)s %(coltyp)s;'%locals()
         try:
             self.db.execute(sql)
@@ -1274,7 +1281,7 @@ class RecData (Pluggable):
 
     def do_add_and_return_item (self, table, dic, id_prop='id'):
         result_proxy = self.do_add(table,dic)
-        select = table.select(getattr(table.c,id_prop)==result_proxy.lastrowid)
+        select = table.select(getattr(table.c,id_prop)==result_proxy.inserted_primary_key[0])
         return select.execute().fetchone()
 
     def do_add_ing (self,dic):
@@ -1301,7 +1308,7 @@ class RecData (Pluggable):
             else:
                 raise ValueError('New recipe created with preset id %s, but ID is not in our list of new_ids'%rdict['id'])
         insert_statement = self.recipe_table.insert()
-        select = self.recipe_table.select(self.recipe_table.c.id==insert_statement.execute(**rdict).lastrowid)
+        select = self.recipe_table.select(self.recipe_table.c.id==insert_statement.execute(**rdict).inserted_primary_key[0])
         return select.execute().fetchone()
 
     def validate_ingdic (self,dic):
@@ -1326,6 +1333,7 @@ class RecData (Pluggable):
     def do_modify (self, table, row, d, id_col='id'):
         if id_col:
             try:
+                self._force_unicode(d)
                 qr = table.update(getattr(table.c,id_col)==getattr(row,id_col)).execute(**d)
             except:
                 print 'do_modify failed with args'
