@@ -75,37 +75,11 @@ class ConvenientImporter (importer.Importer):
         self.group = txt.strip()
 
     def add_ing_from_text (self, txt):
-        try:
-            txt=unicode(txt.strip())
-        except UnicodeDecodeError:
-            print 'Weird -- ignoring unicode error with ',txt
-            txt = txt.strip()
-        txt = re.sub('\s+',' ',txt)
-        if not txt: return        
-        mm = convert.ING_MATCHER.match(txt)
-        if mm:
-            amount = mm.group(convert.ING_MATCHER_AMT_GROUP)
-            unit = mm.group(convert.ING_MATCHER_UNIT_GROUP)
-            item = mm.group(convert.ING_MATCHER_ITEM_GROUP)
-            #print 'Parsed ingredient: "%s"'%txt,"into:",amount,'|',unit,'|',item
-            # If our unit isn't familiar and is longer than 2
-            # characters, don't add it as a unit! (this lets most
-            # abbreviations through)
-            if unit and not self.conv.unit_dict.has_key(unit.strip()) and len(unit.strip())>2:
-                item = unit + ' ' + item
-                unit = ''
-        else:
-            print 'Unable to parse ingredient from text "%s"'%txt
-            print 'Setting amount and unit to None'
-            amount = None; unit = None;
-            item = txt
-        self.start_ing()
-        if amount:
-            self.add_amt(amount)
-        if unit:
-            self.add_unit(unit)
-        if item:
-            self.add_item(item)
+        if not hasattr(self,'db'):
+            import gourmet.backends.db as db
+            self.db = db.get_database()
+        parsed_dict = self.db.parse_ingredient(txt)
+        self.ing = parsed_dict
         self.commit_ing()
 
     def add_ings_from_text (self, txt, break_at='\n'):
@@ -114,7 +88,7 @@ class ConvenientImporter (importer.Importer):
         By default, there is one ingredient per line of text."""
         txt=txt.strip()
         for i in txt.split(break_at):
-            self.add_ing_from_text(i)
+            self.add_ing_from_text(i.strip())
 
 class InteractiveImporter (ConvenientImporter, NotThreadSafe):
 
@@ -246,7 +220,8 @@ class InteractiveImporter (ConvenientImporter, NotThreadSafe):
         else:
             # Otherwise, there's no clear sane default... we'll just
             # select the current whole line
-            cur_pos = self.tb.get_insert()
+            cur_mark = self.tb.get_insert()
+            cur_pos=gtk.TextBuffer.get_iter_at_mark(cur_pos)
             cur_pos.backward_chars(
                 cur_pos.get_line_offset())
             st = cur_pos
@@ -479,7 +454,10 @@ class InteractiveImporter (ConvenientImporter, NotThreadSafe):
                 self.add_attribute('yields',text)
                 self.add_attribute('yield_unit','servings')
             else:
-                print 'UNKNOWN TAG',tag,text,label
+                try:
+                    print 'UNKNOWN TAG',tag,text,label
+                except UnicodeError:
+                    print 'UNKNOWN TAG (unprintable)'
         if started: self.commit_rec()
         if hasattr(self,'images') and self.images:
             # This is ugly -- we run the dialog once per recipe. This
@@ -510,8 +488,8 @@ class InteractiveImporter (ConvenientImporter, NotThreadSafe):
 
     def set_text (self, txt):
         txt = unicode(txt) # convert to unicode for good measure
-        txt = self.parser.parse(txt) # Parse
         txt = re.sub('(\n\s*\n)+','\n\n',txt) # Take out extra newlines
+        txt = self.parser.parse(txt) # Parse
         self.set_parsed(txt)
 
     def set_parsed (self, parsed):
